@@ -6,9 +6,12 @@
   (my $dir = cwd) =~ s/tools$//;
   open FILE, ">$dir/MANIFEST";
 
-  find ({ wanted => sub { 
-                        s/^.*\///; 
-                        $File::Find::dir =~ s/$File::Find::topdir\/?//;
+  chdir '../';
+  my $topdir = cwd;
+
+  find ({ follow=>1, wanted => sub { 
+                        s/^.*\///;
+                        $File::Find::dir =~ s/$topdir\/?//;
                         print FILE ($File::Find::dir ? $File::Find::dir."/$_" : $_)."\n" if !/^(\.|CVS|Root|Repository|Entries)/ && !-d; 
                     }
         }, $dir);
